vivid.art.cli

art-cli public API.

art-cli public API.
raw docstring

art-filename-suffixclj

Ash Ra Template .art filename suffix.

Ash Ra Template .art filename suffix.
sourceraw docstring

art-filename-suffix-regexclj

Ash Ra Template .art filename suffix as a regular expression, suitable for matching filenames.

Ash Ra Template .art filename suffix as a regular expression, suitable for matching filenames.
sourceraw docstring

batch-from-cli-argsclj

(batch-from-cli-args args)

Converts CLI arguments into an ART processing batch using the CLI args specification provided by this library.

Converts CLI arguments into an ART processing batch using
the CLI args specification provided by this library.
sourceraw docstring

default-optionsclj

source

render-batchclj

(render-batch batch)

Scans :templates for files and directory subtrees, renders all ART templates found within according to the batch settings. Fails fast in event of an error.

Scans :templates for files and directory subtrees, renders all ART templates found
within according to the batch settings. Fails fast in event of an error.
sourceraw docstring

render-batchesclj

(render-batches batch-coll)

Render a collection of batches.

Render a collection of batches.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries