vivid.art.cli.args


cli-args->batchclj

(cli-args->batch args options-spec)

Interpret command line arguments, producing a map representing an ART render batch job that can be executed by this CLI lib's (render-batch) fn. All arguments are validated according to the clojure.tools.cli -compliant options specification and resolved. Exceptional cases are signaled.

Interpret command line arguments, producing a map representing an ART render
batch job that can be executed by this CLI lib's (render-batch) fn. All
arguments are validated according to the clojure.tools.cli -compliant options
specification and resolved. Exceptional cases are signaled.
sourceraw docstring

direct->batchclj

(direct->batch templates options)
source

validate-as-batchclj

(validate-as-batch templates {:keys [output-dir] :as options})

Validates template paths, and resolves and validates everything else, returning a render batch.

Validates template paths, and resolves and validates everything else,
returning a render batch.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries