vivid.art.cli.render+


render-template-at-filesystem-pathclj

(render-template-at-filesystem-path path options)

Reads in as a string the contents of the file at path on the filesystem (assuming the default character encoding) and renders it.

Reads in as a string the contents of the file at path on the filesystem
(assuming the default character encoding) and renders it.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries