vivid.art.cli.validate

Validation of individual options available in public API & CLI.

Validation of individual options available in public API & CLI.
raw docstring

validate-bindingsclj

(validate-bindings bindings)

Is either a single or collection of binding maps. Each binding definition is a Clojure map, a Clojure var, a string path to an EDN or JSON file, or a stringified EDN literal map.

Is either a single or collection of binding maps. Each
binding definition is a Clojure map, a Clojure var, a string path to an
EDN or JSON file, or a stringified EDN literal map.
sourceraw docstring

validate-delimitersclj

(validate-delimiters x)

ART is lenient in its acceptance of delimiter specifications.

ART is lenient in its acceptance of delimiter specifications.
sourceraw docstring

validate-dependenciesclj

(validate-dependencies x)
source

validate-output-dirclj

(validate-output-dir output-dir)

A string path of the output directory.

A string path of the output directory.
sourceraw docstring

validate-templatesclj

(validate-templates x)

Provided a collection of path specifications for any mix of globs, directories, and files, finds paths of all files satisfying each path-spec and returns them as a collection of template file path metadata. Any uninterpretable path specification is signaled as an error.

Provided a collection of path specifications for any mix of globs,
directories, and files, finds paths of all files satisfying each path-spec
and returns them as a collection of template file path metadata.
Any uninterpretable path specification is signaled as an error.
sourceraw docstring

validate-to-phaseclj

(validate-to-phase x)

The :to-phase option can either be a valid keyword or its string representation. Returns the valid keyword, otherwise nil.

The :to-phase option can either be a valid keyword or its string representation.
Returns the valid keyword, otherwise nil.
sourceraw docstring

validate-watch-timeout-msclj

(validate-watch-timeout-ms x)

Returns the requested value clamped on the lower bound to a minimum, implementation-dependent value.

Returns the requested value clamped on the lower bound to a minimum,
implementation-dependent value.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries