vivid.art.cli.watch


batch->handlersclj

(batch->handlers acc batch')

Lists handlers for each of the template paths in a batch.

Lists handlers for each of the template paths in a batch.
sourceraw docstring

batch-defaultsclj

source

build-directory-watcherclj

(build-directory-watcher listener-fn path)
source

default-debounce-timeout-msclj

io.methvin:directory-watcher:0.17.3 uses a value of 500ms wait period in its automated test suite; we adopt that value here.

io.methvin:directory-watcher:0.17.3 uses a value of 500ms wait period
in its automated test suite; we adopt that value here.
sourceraw docstring

directory-handler-fnclj

(directory-handler-fn _batch f)
source

file-handler-fnclj

(file-handler-fn _batch f)

io.methvin:directory-watcher only handles directories. We work around this limitation by watching the file's parent directory, ignoring all events except those that match the file path.

io.methvin:directory-watcher only handles directories.
We work around this limitation by watching the file's parent directory,
ignoring all events except those that match the file path.
sourceraw docstring

listenerclj

(listener listener-fn)
source

noise-exception-typesclj

source

not-exists-handler-fnclj

(not-exists-handler-fn _ f)
source

watchclj

(watch listener-fn path)

Asynchronously watches for file system changes on the specified path, calling listener-fn on each detected change. This function returns immediately.

Asynchronously watches for file system changes on the specified path,
calling listener-fn on each detected change. This function returns
immediately.
sourceraw docstring

watch-and-sleep!clj

(watch-and-sleep! handlers event-fn)
source

watch-on-batchesclj

(watch-on-batches batches event-fn)

Watches template paths in all supplied batches. Whenever a file system event occurs associated with a batch, calls event-fn with batch.

Watches template paths in all supplied batches.
Whenever a file system event occurs associated with a batch, calls
event-fn with batch.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries