art-cli public API.
art-cli public API.
Ash Ra Template .art filename suffix.
Ash Ra Template .art filename suffix.
Ash Ra Template .art filename suffix as a regular expression, suitable for matching filenames.
Ash Ra Template .art filename suffix as a regular expression, suitable for matching filenames.
(batch-from-cli-args args)Converts CLI arguments into an ART processing batch using the CLI args specification provided by this library.
Converts CLI arguments into an ART processing batch using the CLI args specification provided by this library.
(render-batch batch)Scans :templates for files and directory subtrees, renders all ART templates found within according to the batch settings. Fails fast in event of an error.
Scans :templates for files and directory subtrees, renders all ART templates found within according to the batch settings. Fails fast in event of an error.
(render-batches batch-coll)Render a collection of batches.
Render a collection of batches.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |