(cli-args->batch args options-spec)Interpret command line arguments, producing a map representing an ART render batch job that can be executed by this CLI lib's (render-batch) fn. All arguments are validated according to the clojure.tools.cli -compliant options specification and resolved. Exceptional cases are signaled.
Interpret command line arguments, producing a map representing an ART render batch job that can be executed by this CLI lib's (render-batch) fn. All arguments are validated according to the clojure.tools.cli -compliant options specification and resolved. Exceptional cases are signaled.
(validate-as-batch templates {:keys [output-dir] :as options})Validates template paths, and resolves and validates everything else, returning a render batch.
Validates template paths, and resolves and validates everything else, returning a render batch.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |