(render-template-at-filesystem-path path options)Reads in as a string the contents of the file at path on the filesystem (assuming the default character encoding) and renders it.
Reads in as a string the contents of the file at path on the filesystem (assuming the default character encoding) and renders it.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |