(batch->handlers acc batch')Lists handlers for each of the template paths in a batch.
Lists handlers for each of the template paths in a batch.
io.methvin:directory-watcher:0.17.3 uses a value of 500ms wait period in its automated test suite; we adopt that value here.
io.methvin:directory-watcher:0.17.3 uses a value of 500ms wait period in its automated test suite; we adopt that value here.
(file-handler-fn _batch f)io.methvin:directory-watcher only handles directories. We work around this limitation by watching the file's parent directory, ignoring all events except those that match the file path.
io.methvin:directory-watcher only handles directories. We work around this limitation by watching the file's parent directory, ignoring all events except those that match the file path.
(watch listener-fn path)Asynchronously watches for file system changes on the specified path, calling listener-fn on each detected change. This function returns immediately.
Asynchronously watches for file system changes on the specified path, calling listener-fn on each detected change. This function returns immediately.
(watch-on-batches batches event-fn)Watches template paths in all supplied batches. Whenever a file system event occurs associated with a batch, calls event-fn with batch.
Watches template paths in all supplied batches. Whenever a file system event occurs associated with a batch, calls event-fn with batch.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |